aboutsummaryrefslogtreecommitdiffstats
path: root/src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java
diff options
context:
space:
mode:
authorMarc Englund <marc.englund@itmill.com>2007-11-30 12:38:20 +0000
committerMarc Englund <marc.englund@itmill.com>2007-11-30 12:38:20 +0000
commit59f513cc239fa3cbe3459da70baa81584eb17206 (patch)
treeee5ce4eee88811224187209bb74722d56fd51ba2 /src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java
parent6b69b2bcecddff8f4243c8a14cd21de258e8602e (diff)
downloadvaadin-framework-59f513cc239fa3cbe3459da70baa81584eb17206.tar.gz
vaadin-framework-59f513cc239fa3cbe3459da70baa81584eb17206.zip
Label example added
svn changeset:3068/svn branch:trunk
Diffstat (limited to 'src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java')
-rw-r--r--src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java41
1 files changed, 22 insertions, 19 deletions
diff --git a/src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java b/src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java
index 62e023dd17..d8081ebce7 100644
--- a/src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java
+++ b/src/com/itmill/toolkit/demo/featurebrowser/FeatureBrowser.java
@@ -45,30 +45,33 @@ public class FeatureBrowser extends com.itmill.toolkit.Application implements
private static final Object[][] demos = new Object[][] {
// Category, Name, Desc, Class, Viewed
- // Basic: Labels
- { "Basic", "Labels", "Some variations of Labels", Button.class,
- Boolean.FALSE },
- // Basic: Buttons
- { "Basic", "Buttons and links",
+ // Getting started: Labels
+ { "Getting started", "Labels", "Some variations of Labels",
+ LabelsExample.class, Boolean.FALSE },
+ // Getting started: Buttons
+ { "Getting started", "Buttons and links",
"Some variations of Buttons and Links", Button.class,
Boolean.FALSE },
- // Basic: Fields
- { "Basic", "User input", "TextFields, DateFields, and such",
- Button.class, Boolean.FALSE },
+ // Getting started: Fields
+ { "Getting started", "User input",
+ "TextFields, DateFields, and such", Button.class,
+ Boolean.FALSE },
//
- { "Basic", "RichText", "Rich text editing", RichTextExample.class,
+ { "Getting started", "RichText", "Rich text editing",
+ RichTextExample.class, Boolean.FALSE },
+ // Getting started: Selects
+ { "Getting started", "Choices, choices",
+ "Some variations of simple selects", Button.class,
Boolean.FALSE },
- // Basic: Selects
- { "Basic", "Choices, choices", "Some variations of simple selects",
- Button.class, Boolean.FALSE },
- // Organizing: ComboBox
- { "Organizing", "ComboBox", "ComboBox - the swiss army select",
+ // Wrangling data: ComboBox
+ { "Wrangling data", "ComboBox", "ComboBox - the swiss army select",
ComboBoxExample.class, Boolean.FALSE },
- // Organizing: Table
- { "Organizing", "Table", "A dynamic Table with bells and whistles",
- Button.class, Boolean.FALSE },
- // Organizing: Tree
- { "Organizing", "Tree", "Some variations of Buttons and Links",
+ // Wrangling data: Table
+ { "Wrangling data", "Table",
+ "A dynamic Table with bells and whistles", Button.class,
+ Boolean.FALSE },
+ // Wrangling data: Tree
+ { "Wrangling data", "Tree", "Some variations of Buttons and Links",
TreeExample.class, Boolean.FALSE },
// Misc: Notifications
{ "Misc", "Notifications", "Notifications can improve usability",